# cumbia-project-tools

This project gathers a set of *bash* scripts to manage projects within 
a developer's *directory structure that mirrors a correspondent project
organization on gitlab, employing groups*.

The optimal use case is in fact a local folder hierarchy that exactly
mimics how projects are organized on *gitlab*, under *gitlab groups*

Main scripts:

1. cumbia-project-search.sh (search locally and remotely)
2. cumbia-project-git.sh (manage synchronization)
3. cumbia-project-build.sh (project compilation helper)
4. cumbia-project-new.sh (create a new project,  locally)
5. cumbia-project-inau.sh (interface with *Elettra's INAU* installation system)

Bash completion scripts help the user providing shortcuts for the most
relevant functions and auto completion.

## General rules

### First run configuration

To run the tools, a file named *user.conf* under */home/yourname/.config/cumbia-project-tools* 
directory must be configured. 

> cumbia-project-new.sh -i

creates the file for you under */home/yourname/.config/cumbia-project-tools*

Edit the file so that the following lines are valid:

# user name (home)
- user="your-name"
- author=$user
- organization=Elettra Sincrotrone Trieste
- location=Office information
- phone=1234
- mail=name.surname@elettra.eu

Then, in the ensuing gitlab section, make sure that

- gitlab_user="gitlab.user"
- gitlab_token="my-gitlab-personal-access-token"
- gitlab_url="https://gitlab.elettra.eu"

are correct in order to use gitlab integration from cumbia-project-tools.
S
To integrate the scripts with *INAU*, complete the lines:

- inau_host="https://inau.elettra.eu"
- inau_user="giacomo.strangolino"

### Project and group names

The scripts require a project name to work with. If unspecified explicitly,
in several cases it is taken from the current working directory.

- /home/user/devel/cs/gui/appli --> name *appli*

The same goes for the *groups*. If unspecified, it is either guessed by the
local directory or from the gitlab group:

- /home/user/devel/cs/gui/appli --> group *cs/gui*
- https://gitlab.elettra.eu/cs/lib/cumbia/cumbia-qtcontrols --> group *cs/lib/cumbia*

*gitlab* groups that are relevant to the developer shall be listed in the 
*cumbia-project-tools* configuration file.

### Critical operations

Some critical operations (such as project creation or installation on the
field) require an additional *execute* parameter, after double checking 
where and how the operations will be performed.

## cumbia project search


## Release and install a project

### Release

#### script: 

*cumbia-project-git.sh*

##### help 

> cumbia-project-git.sh -h

Assume we are working inside the directory project.
First commit any modified code:

> cumbia project sync -m "commit message"

Review and execute adding *-x* to the command above.

Then tag. If unspecified, the message is gathered from *git log* in order to provide all the commit messages since the 
previous tag. The release tag is calculated automatically.

> cumbia project release 

Check if you are happy with that, and re-execute the command with the *-x* switch to *execute*.

Otherwise

> cumbia project release -m "a message" -x

### Install (Elettra INAU)

#### script:

*cumbia-project-inau.sh*

##### help

> cumbia-project-inau.sh -h

Again from the project directory

> cumbia project install 

Review the command that *would be* imparted and then confirm re executing the same instructions with the *-x* switch. Insert
the password when prompted.

