# Source the git completion file
source ${CUMBIA_INSTALL_ROOT}/share/bash_completion.d/src/10-cumbia.sh

_is_project_type()
{
    type=$1
    i=1  # Start from COMP_CWORD - 1
    while (( COMP_CWORD - i >= 1 )); do
        current_word="${COMP_WORDS[COMP_CWORD - i]}"
        prev_word="${COMP_WORDS[COMP_CWORD - i - 1]}"
        if [[ "$current_word" == "$type" ]] && [[ "$prev_word" == "project" ]]; then
            echo "yes"
            break
        fi
        ((i++))
    done

    if (( COMP_CWORD - i < 1 )); then
        echo "no"
    fi
}

_cumbia_project()
{
    local cur prev prevprev cumbiacompl proopts base
    COMPREPLY=()
    cur="${COMP_WORDS[COMP_CWORD]}"
    prev="${COMP_WORDS[COMP_CWORD-1]}"
    prevprev="${COMP_WORDS[COMP_CWORD-2]}"

    # load _cumbia() completions
    _cumbia

    # Store the original completions in a variable for later use
    cumbiacompl=("${COMPREPLY[@]}")

    # Define your additional custom options
    proopts=( "project" )


    #
    #  The basic options we'll complete.
    #
    proopts="project"

   # echo -e "\e[1;32m prev ${prev} prevprev ${prevprev}\e[0m"
    case "${prev}" in
        project)
            local running=$(for x in new search sync create clone release log lastlog install inau-search port2cmake; do echo ${x} ; done )
            COMPREPLY=( $(compgen -W "${running}" -- ${cur}) )
            return 0
            ;;
        new)
            if [[ "$(_is_project_type "new")" == "yes" ]]; then
                local running=$(for x in "project_name"; do echo ${x} ; done )
                COMPREPLY=( $(compgen -W "${running}" -- ${cur}) )
                return 0
            fi
        ;;
        sync|create|lastlog|log|release|search|new|install)
            local running=$(for x in project-name; do echo ${x} ; done )
            COMPREPLY=( $(compgen -W "${running}" -- ${cur}) )
            return 0
        ;;
#        search)
#            echo "in search!"
#            local searchopts=$(for x in list remote exact remote-only list-dev-dirs; do echo ${x} ; done )
#            COMPREPLY=( $(compgen -W "${searchopts}" -- ${cur}) )
           # return 0
#            ;;
    esac

    if [[ "$(_is_project_type "new")" == "yes" ]]; then
        local running=$(for x in $(cumbia-project-new.sh -O); do echo ${x} ; done )
        COMPREPLY=( $(compgen -W "${running}" -- ${cur}) )
        return 0
    elif [[ "$(_is_project_type "search")" == "yes" ]]; then
        local running=$(for x in $(cumbia-project-search.sh -O); do echo ${x} ; done )
        COMPREPLY=( $(compgen -W "${running}" -- ${cur}) )
        return 0
    elif [[ "$(_is_project_type "lastlog")" == "yes" ]] || \
         [[ "$(_is_project_type "log")" == "yes" ]] || \
         [[ "$(_is_project_type "release")" == "yes" ]] || \
         [[ "$(_is_project_type "sync")" == "yes" ]]; then
            local running=$(for x in $(cumbia-project-git.sh -O); do echo ${x} ; done )
            COMPREPLY=( $(compgen -W "${running}" -- ${cur}) )
            return 0
    elif [[ "$(_is_project_type "install")" == "yes" ]]; then
        local running=$(for x in $(cumbia-project-inau.sh -O "install"); do echo ${x} ; done )
        COMPREPLY=( $(compgen -W "${running}" -- ${cur}) )
        return 0
    elif [[ "$(_is_project_type "inau-search")" == "yes" ]]; then
        local running=$(for x in $(cumbia-project-inau.sh -O "search"); do echo ${x} ; done )
        COMPREPLY=( $(compgen -W "${running}" -- ${cur}) )
        return 0
    fi


    # echo -e "prevprev=\e[1;32m${prevprev}\e[0m\n"
    case "${prevprev}" in
        search)
            local running=$(for x in $(cumbia-project-search.sh -O); do echo ${x} ; done )
            COMPREPLY=( $(compgen -W "${running}" -- ${cur}) )
            return 0
            ;;
        git)
            local running=$(for x in sync release create log lastlog; do echo ${x} ; done )
            COMPREPLY=( $(compgen -W "${running}" -- ${cur}) )
            return 0
            ;;
        esac

    # Combine original git completions with your new ones
    if [[ "${prev}" == "cumbia" ]]; then
        # show all the options, including project related
        COMPREPLY=( $(compgen -W "${proopts} ${cumbiacompl[*]}" -- "$cur") )
    elif [[ "${prevprev}" != "search" ]] && [[ "${prevprev}" != "new" ]]; then
           # echo "prevprev is one of search or new"
        # show only 'cumbia' base options
        COMPREPLY=( $(compgen -W "${cumbiacompl[*]}" -- "$cur") )
    fi
    return 0
}


# Override the cumbia completion with the new function
complete -F _cumbia_project cumbia
