#!/bin/bash

source cumbia-project-search-functions.sh
source cumbia-project-init-conf-functions.sh

# Variables from config file
declare -a dev_dirs
make_command=""
cmake_conf=""

# Function to load the configuration file
load_config() {
    if [[ -f "$CONFIG_FILE" ]]; then
        source "$CONFIG_FILE"
        if [[ ${#dev_dirs[@]} -eq 0 ]]; then
            echo -e "[\e[1;31mNO\e[0m]: missing \"dev_dirs\" (${#dev_dirs[@]})  directive in '$CONFIG_FILE'"
            exit 1
        fi
        if [[ -z "$make_command" ]]; then
            echo -e "[\e[1;31mNO\e[0m]: missing \"make_command\" directive in '$CONFIG_FILE'"
            exit 1
        fi
        if [[ -z "$cmake_conf" ]]; then
            echo -e "[\e[1;31mNO\e[0m]: missing \"cmake_conf\" directive in '$CONFIG_FILE'"
            exit 1
        fi
    else
        echo "Configuration file not found at $CONFIG_FILE."
        echo "Please run the script with the -i option to initialize a draft configuration file."
        exit 1
    fi
}

print_options() {
    echo "-l -s search -d(dir-leaf) -e(exact-match) -r(remote) -R(remote-only) -L(list-dev-dirs)"
}

# load configuration.
load_config

# Parse command-line options
while getopts "iLls:d:p:etfrRO" opt; do
    case ${opt} in
        i )
            initialize_config_opt=true
            ;;
        L )
            list_dev_dirs
            ;;
        l )
            list=true
            ;;
        s )
            search_str=$OPTARG
            ;;
        d )
            dir_leaf=$OPTARG
            ;;
        t )
            type_opt=true
            if [ -n "$OPTARG" ]; then
                project_name=$OPTARG
            fi
            ;;
        f )
            force_overwrite_conf=true
            ;;
        e )
            exact_match=true
            ;;
        r )
            remote=true
            ;;
        R )
            remote_only=true
            remote=true
            ;;
        O )
            print_options
            exit 0
            ;;
        \? )
            echo -e "Usage:\n\n $0 \n\n" \
                   " -s \e[1;32msearch-string\e[0m (search projects locally)\n" \
                   " -r (with -s, include \e[1;32mremote\e[0m search (git) ) \n" \
                   " -R (with -s, \e[1;32mremote\e[0m search \e[1;32;4monly\e[0m)\n\n" \
                   " -l (\e[1;32mlist\e[0m projects)\n" \
                   " -L (list devel dirs as listed in the configuration file)\n" \
                   " -i (initialize configuration file, -f to overwrite)\n" \
                   " -t (get project \e[1;32mtype\e[0m: cmake/qmake)\n\n"
            exit 1
            ;;
    esac
done

if [[ "$initialize_config_opt" == true ]]; then
    # from source'd cumbia-project-init-conf-functions.sh
    init_config
fi

# List all projects in a development directory (-l)
if [[ "$list" == true ]]; then
    list_projects
elif [[ -n "$search_str" ]]; then
    if [[ -z "$remote_only" ]]; then
        local_pro=$(local_search  $search_str $exact_match)
    fi
    if [[ -n "$remote" ]]; then
        check_gitlab_config
        if gitlab_groups_enabled; then
            json_remote_pro=$(gitlab_group_search "$search_str")
        else
            json_remote_pro=$(gitlab_search "$search_str")
        fi
        remote_pro=$(json_extract  "$json_remote_pro" "$search_str" "$exact_match")
    elif gitlab_enabled; then
        hints+=("use \e[1;3m$0 -s $search_str \e[1;32;3m-r\e[0m\e[0m to include results from $gitlab_url")
    fi

    for r in "${local_pro[@]}"; do
        echo "$r"
    done
    for r in "${remote_pro[@]}"; do
    echo "$r"
done
elif [[ "$type_opt" == true ]]; then
    get_project_type
fi

for h in "${hints[@]}"; do
    echo -e "[ \e[1;33mHINT\e[0m ]: $h"
done

